<?php

namespace Hrm\Cessation\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hrm\Cessation\Models\Cessation;

class CessationPolicy
{

    /**
     * Determine if the given user can view the cessation.
     *
     * @param UserPolicy $user
     * @param Cessation $cessation
     *
     * @return bool
     */
    public function view(UserPolicy $user, Cessation $cessation)
    {
        if ($user->canDo('cessation.cessation.view') && $user->isAdmin()) {
            return true;
        }

        return $cessation->user_id == user_id() && $cessation->user_type == user_type();
    }

    /**
     * Determine if the given user can create a cessation.
     *
     * @param UserPolicy $user
     * @param Cessation $cessation
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('cessation.cessation.create');
    }

    /**
     * Determine if the given user can update the given cessation.
     *
     * @param UserPolicy $user
     * @param Cessation $cessation
     *
     * @return bool
     */
    public function update(UserPolicy $user, Cessation $cessation)
    {
        if ($user->canDo('cessation.cessation.edit') && $user->isAdmin()) {
            return true;
        }

        return $cessation->user_id == user_id() && $cessation->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given cessation.
     *
     * @param UserPolicy $user
     * @param Cessation $cessation
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Cessation $cessation)
    {
        return $cessation->user_id == user_id() && $cessation->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given cessation.
     *
     * @param UserPolicy $user
     * @param Cessation $cessation
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Cessation $cessation)
    {
        if ($user->canDo('cessation.cessation.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given cessation.
     *
     * @param UserPolicy $user
     * @param Cessation $cessation
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Cessation $cessation)
    {
        if ($user->canDo('cessation.cessation.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
